/*
 * NewsBlob - Live RSS news reader.
 * Copyright 2009 Lars Torger Høye.
 *
 * This file is part of NewsBlob.
 *
 * NewsBlob is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * NewsBlob is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with NewsBlob.  If not, see <http://www.gnu.org/licenses/>.
 */

package newsblob;

import newsblob.feed.file.NewsfeedsFile;
import newsblob.blob.Blob;
import java.awt.AWTException;
import java.awt.SystemTray;
import java.awt.TrayIcon;
import java.io.FileNotFoundException;
import java.io.IOException;
import javax.swing.ImageIcon;
import javax.xml.parsers.ParserConfigurationException;
import javax.xml.xpath.XPathExpressionException;
import newsblob.feed.Newsfeed;

/**
 *
 * @author Lars Torger Høye
 */
public class NewsBlob {

    private Blob m_blob;
    private TrayIcon m_trayIcon;

    private NewsfeedsFile m_newsfeedsFile;

    private static NewsBlob m_instance;

    public static final String TITLE = "NewsBlob";
    public static final String VERSION = "0.2.1";
    public static final String COPYRIGHT = "Copyright 2009 Lars Torger Høye.";

    private NewsBlob() {
        TrayIcon newsIcon = new TrayIcon(new ImageIcon("news.gif").getImage(), TITLE);
        m_blob = new Blob(newsIcon);
        m_trayIcon = new TrayIcon(new ImageIcon("icon.png").getImage(), TITLE);
    }
    
    public static NewsBlob getInstance() {
        if(m_instance == null)
            m_instance = new NewsBlob();
        return m_instance;
    }

    public void run(boolean local) throws AWTException, FileNotFoundException, IOException {
        SystemTray.getSystemTray().add(m_trayIcon);
        
        if(local) {
            m_newsfeedsFile = new NewsfeedsFile("Newsfeeds");
            m_newsfeedsFile.load(m_blob);
        }

        m_trayIcon.setPopupMenu(NewsBlobMenu.getInstance().getMenu());
    }

    public void add(Newsfeed newsfeed) throws ParserConfigurationException, XPathExpressionException, FileNotFoundException, IOException, Exception {
        m_blob.add(newsfeed);
        if(m_newsfeedsFile != null)
            m_newsfeedsFile.add(newsfeed);
    }

    public void remove(Newsfeed newsfeed) throws FileNotFoundException, IOException {
        if(m_newsfeedsFile != null)
            m_newsfeedsFile.remove(newsfeed);
        m_blob.remove(newsfeed);
    }

    public void exit() {
        m_blob.close();

        SystemTray sysTray = SystemTray.getSystemTray();
        sysTray.remove(m_trayIcon);
    }
}
