/*
 * NewsBlob - Live RSS news reader.
 * Copyright 2009 Lars Torger Høye.
 *
 * This file is part of NewsBlob.
 *
 * NewsBlob is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * NewsBlob is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with NewsBlob.  If not, see <http://www.gnu.org/licenses/>.
 */

package newsblob.feed;

/**
 *
 * @author Lars Torger Høye
 */
public class Newsfeed {

    private final String m_title;
    private final String m_uri;
    private final int m_updateFrequenzy;       //in minutes
    private final int m_displayTime;           //in seconds

    private String m_noChache = "?noCache=";
    private long m_noCacheNum = System.currentTimeMillis();

    public Newsfeed(String title, String url, int updateFrequenzy, int displayTime) {
        m_title = title;
        m_uri = url;
        m_updateFrequenzy = updateFrequenzy;
        m_displayTime = displayTime;

        if(m_uri.indexOf("?") != -1)
            m_noChache = "&noCache=";
    }

    public String getTitle() {
        return m_title;
    }

    public String getURI() {
        return m_uri;
    }

    public String getUniqueURI() {
        return m_uri+m_noChache+(m_noCacheNum++);
    }

    public long getUpdateFrequenzy() {
        return m_updateFrequenzy;
    }

    public long getDisplayTime() {
        return m_displayTime;
    }

    public boolean equals(Newsfeed newsfeed) {
        if(m_uri.equals(newsfeed.getURI()))
            return true;
        return false;
    }
}
