/*
 * NewsBlob - Live RSS news reader.
 * Copyright 2009 Lars Torger Høye.
 *
 * This file is part of NewsBlob.
 *
 * NewsBlob is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * NewsBlob is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with NewsBlob.  If not, see <http://www.gnu.org/licenses/>.
 */

package newsblob.feed.file;

import newsblob.feed.*;

/**
 *
 * @author Lars Torger Høye
 */
public class NewsfeedFormat {
    
    private int m_title = -1;
    private int m_uri = -1;
    private int m_updateFrequenzy = -1;
    private int m_displayTime = -1;

    public NewsfeedFormat(String line) {
        String[] format = line.split(";");
            for (int i = 0; i < format.length; i++) {
                if(format[i].trim().equals("title"))
                    m_title = i;
                else if(format[i].trim().equals("url"))
                    m_uri = i;
                else if(format[i].trim().equals("updatefrequenzy"))
                    m_updateFrequenzy = i;
                else if(format[i].trim().equals("displaytime"))
                    m_displayTime = i;
            }
    }

    public Newsfeed decodeNewsfeed(String line) {
        if(m_title == -1 || m_uri == -1 || m_updateFrequenzy == -1 || m_displayTime == -1) return null;

        String[] sNewsfeed = line.split(";");
        return new Newsfeed(
                sNewsfeed[m_title].trim(),
                sNewsfeed[m_uri].trim(),
                Integer.parseInt(sNewsfeed[m_updateFrequenzy].trim()),
                Integer.parseInt(sNewsfeed[m_displayTime].trim()));
    }

    public String encodeNewsfeed(Newsfeed newsfeed) {
        String[] out = new String[4];
        
        out[m_title] = filterText(newsfeed.getTitle());
        out[m_uri] = newsfeed.getURI();
        out[m_updateFrequenzy] = String.valueOf(newsfeed.getUpdateFrequenzy());
        out[m_displayTime] = String.valueOf(newsfeed.getDisplayTime());

        return out[0]+"; "+out[1]+"; "+out[2]+"; "+out[3]+"\n";
    }

    /**
     * Filters text for storage on disk by removing reserved symbols
     *
     * @param text text to filter.
     * @return filtered text.
     */
    private String filterText(String text) {
        text = text.replace(';', ',');
        return text.replace('#', ' ');
    }
}
